@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Primitive.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -29,14 +27,12 @@
 package G::DB::SDB;
 
 use strict;
-use Storable qw(nstore retrieve);
+use base qw(Exporter);
+use autouse 'Storable'=>qw(nstore retrieve);
+
 use File::Basename;
 use G::Messenger;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 		 sdb_save
 		 sdb_load
