@@ -43,7 +43,7 @@ require G::IO::EmblI;
 use File::Basename;
 use File::ShareDir ':ALL';
 
-our $VERSION = '1.8.4';
+our $VERSION = '1.8.5';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -323,26 +323,6 @@ sub loaded_msg {
     &msg_error($print);
 }
 
-sub set_gene_aliases{
-    my $this = shift;
-
-    foreach my $feat ($this->feature()){
-	next unless ($this->{$feat}->{type} =~ /CDS|RNA/);
-	
-	if(length $this->{$feat}->{gene}){
-	    $this->{$this->{$feat}->{gene}} = $this->{$feat};
-	}
-	
-	if(length $this->{$feat}->{locus_tag}){
-	    $this->{$this->{$feat}->{locus_tag}} = $this->{$feat};
-	}
-	
-	if($this->{$feat}->{type} eq 'CDS'){
-	    $this->{'CDS' . $this->{$feat}->{cds}} = $this->{$feat};
-	}
-    }
-}
-
 sub interpret_format {
     my $filename = shift;
     my $ref = ref $filename;
