@@ -217,15 +217,15 @@ sub read_features{
 		}
 
 		my $line = $_;
-		my $fth = '';
+		my $fth = $line;
 		my $linenum = tell GENBANK;
 
-		while($line !~ /\//){
-		    $fth .= $line;
-		    last unless ($line =~ /^ {6}/);
-		    $line = <GENBANK>;
+		while(<GENBANK>){
+		    $line = $_;
 		    $linenum = tell GENBANK;
 		    $linenum -= length($line);
+		    last if($line =~ /\//);
+		    $fth .= $line;
 		}
 		seek GENBANK, $linenum, 0;
 
