@@ -66,7 +66,7 @@ sub make_gb {
 		 $gb->{LOCUS}->{date});
 
     printf OUT "%-11.11s %-10.10s %-12.12s %-5.5s %-9.9s %-9.9s%-10.10s\n",@locus;
-    printf OUT "$gb->{HEADER}$gb->{COMMENT}FEATURES %11sLocation/Qualifiers\n";
+    printf OUT "%s%sFEATURES %11s Location/Qualifiers\n", $gb->{HEADER}, $gb->{COMMENT};
 
     foreach my $feat ($gb->feature()){
 	if($gb->{$feat}->{"direction"} eq "direct"){
