@@ -71,6 +71,30 @@ Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 #    Let the code begin...
 #::::::::::::::::::::::::::::::
 
+#::::::::: Internal :::::::::::
+
+sub set_gene_aliases{
+    my $this = shift;
+
+    foreach my $feat ($this->feature()){
+	next unless ($this->{$feat}->{type} =~ /CDS|RNA/);
+	
+	if(length $this->{$feat}->{gene}){
+	    $this->{$this->{$feat}->{gene}} = $this->{$feat};
+	}
+	
+	if(length $this->{$feat}->{locus_tag}){
+	    $this->{$this->{$feat}->{locus_tag}} = $this->{$feat};
+	}
+	
+	if($this->{$feat}->{type} eq 'CDS'){
+	    $this->{'CDS' . $this->{$feat}->{cds}} = $this->{$feat};
+	}
+    }
+}
+
+#::::::::: Class Method ::::::::::
+
 sub clone {
     my $this = shift;
     my $sdbPath = _sdb_path();
