@@ -243,9 +243,17 @@ sub find_ori_ter {
      [1] Escherichia coli K12, Bacillus subtilis, Haemophilus influenzae
      [2] Salmonella typhi
 
+    If "rep_origin" feature is available, center position within this feature
+    is used for origin. 
+
     If no documentation is available, the origin and terminus is predicted using
     find_ori_ter().
 
+    After calling this function, positions of origin and terminus are stored 
+    as follows:
+      $genome->{FEATURE0}->{origin}
+      $genome->{FEATURE0}->{terminus}
+
  Usage: 
     ($ori, $ter) = rep_ori_ter($genome);
 
@@ -261,6 +269,7 @@ sub find_ori_ter {
  Author: Kazuharu Arakawa
 
  History:
+    20080428-01 added support for "rep_origin" feature
     20011030-01 initial posting
 
 =cut
@@ -291,9 +300,19 @@ sub rep_ori_ter {
 	    $ori = 3765000 - 1;
 	    $ter = 1437000 - 1;
 	}else{
+	    msg_error('Using find_ori_ter() to predict...' . "\n");
 	    ($ori, $ter) = &G::Seq::GCskew::find_ori_ter($gb, -output=>"/dev/null");
 	}
-	
+
+	my $interface = msg_ask_interface();
+	msg_interface('NULL');
+	my $cds = ($gb->find(-type=>'rep_origin'))[0];
+	if($cds){
+	    $ori = int(($gb->{$cds}->{end} + $gb->{$cds}->{start})/2) - 1;
+	    msg_error("rep_origin feature found. Using $ori as origin.\n");
+	}
+	msg_interface($interface);
+
 	$gb->{FEATURE0}->{origin} = $ori;
 	$gb->{FEATURE0}->{terminus} = $ter;
     }
