@@ -156,23 +156,29 @@ my $pi = 4 * atan2(1,1);
     NULL = circular_map($gb);
 
  Options:
-    None.
+    -gmap           1 to create Google Map view, 0 to only generate PNG image
+                    (default:1)
 
   Author: 
     Nobuhiro Kido (t07505nk@sfc.keio.ac.jp)
 
   History:
+   20080414-01 added gmap option
    20071023-01 initial posting
 
 =cut
 
 
 sub circular_map{
-    my $gb = opt_as_gb(shift);
-
+    opt_default("gmap"=>1);
+    my @args = opt_get(@_);
+    my $gb = opt_as_gb(shift @args);
+    my $gmap = opt_val("gmap");
     mkdir( "data", 0777 );
     mkdir( "graph",  0777 );
 
+    msg_error("Map generation will take a few minutes. Please make yourself comfortable until the image is generated ;-\)\n\n") if ($gmap);
+
     my $wfile = $gb->{LOCUS}->{id};
     my ( $ori, $ter ) = find_ori_ter( $gb, -output => "/dev/null" );
     my $bp_length = length( $gb->{SEQ} );
@@ -313,7 +319,7 @@ sub circular_map{
         $cdst->text( x => $xe, y => $ye, 'font-size' => 100 )->cdata("ORIGIN");
     }
 
-    my ( $xe, $ye ) = &get_pos( $ter, 4000, $bp_length );
+    ($xe, $ye ) = &get_pos( $ter, 4000, $bp_length );
     $oriter->path( 'd' => "M$cx,$cy L$xe,$ye" );
 
     if ( $xe < $cx ) {
@@ -345,12 +351,12 @@ sub circular_map{
     $sclc->circle( cx => $cx, cy => $cy, r => 3680 );
 
     while ( $i < $bp_length ) {
-        my ( $xe, $ye ) = &get_pos( $i, 3700, $bp_length );
+        ( $xe, $ye ) = &get_pos( $i, 3700, $bp_length );
         $scla->path( 'd' => "M$cx,$cy L$xe,$ye" );
         $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
-        my ( $xe, $ye ) = &get_pos( $i, 2850, $bp_length );
+        ( $xe, $ye ) = &get_pos( $i, 2850, $bp_length );
         $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
-        my ( $xe, $ye ) = &get_pos( $i, 1800, $bp_length );
+        ( $xe, $ye ) = &get_pos( $i, 1800, $bp_length );
         $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
 
         if ( $i % 250000 == 0 ) {
@@ -480,7 +486,7 @@ sub circular_map{
     my $wsize = 2000;           #window_bp_size
     my $step  = 1000;
 
-    my $tag   = $svg->circle(
+    $tag   = $svg->circle(
         cx     => $cx,
         cy     => $cy,
         r      => $bline,
@@ -488,7 +494,7 @@ sub circular_map{
         fill   => 'none'
     );
 
-    my $tag = $svg->circle(
+    $tag = $svg->circle(
         cx     => $cx,
         cy     => $cy,
         r      => $blineg,
@@ -542,6 +548,10 @@ sub circular_map{
     open( WRITER, ">./graph/" . $wfile . ".svg" );
     print WRITER $svg->xmlify;
     close WRITER;
+
+    if($gmap){
+	generateGMap("graph/$wfile.svg");
+    }
 }
 
 sub get_pos {
@@ -584,7 +594,7 @@ sub get_arrow {
     $th -= $pi * 3 / 4;
     my $xl = $xxe + cos($th) * $rl;
     my $yl = $yye + sin($th) * $rl;
-    my $th -= $pi * 2 / 4;
+    $th -= $pi * 2 / 4;
     my $xr = $xxe + cos($th) * $rl;
     my $yr = $yye + sin($th) * $rl;
 
@@ -607,7 +617,7 @@ sub get_arrowc {
     $th -= $pi * 1 / 4;
     my $xl = $xxs + cos($th) * $rl;
     my $yl = $yys + sin($th) * $rl;
-    my $th += $pi * 2 / 4;
+    $th += $pi * 2 / 4;
     my $xr = $xxs + cos($th) * $rl;
     my $yr = $yys + sin($th) * $rl;
 
@@ -1978,21 +1988,27 @@ sub plasmid_map{
     NULL = dnawalk($gb);
 
  Options:
-    None.
+    -gmap           1 to create Google Map view, 0 to only generate PNG image
+                    (default:1)
 
   Author: 
     Keita Ikegami (t06056ki@sfc.keio.ac.jp)
 
   History:
+   20080414-01 added gmap option
    20071023-01 initial posting
 
 =cut
 
 
 sub dnawalk{
-    my $gb = opt_as_gb(shift);
+    opt_default("gmap"=>1);
+    my @args = opt_get(@_);
+
+    my $gb = opt_as_gb(shift @args);
     my $name = $gb->{LOCUS}->{id};
     my $segments = 10;
+    my $gmap = opt_val("gmap");
 
     mkdir("data", 0777);
     mkdir("graph", 0777);
@@ -2004,6 +2020,8 @@ sub dnawalk{
     my ($cds_x, $cds_y);
     my ($out, @out);
     
+    msg_error("Map generation will take a few minutes. Please make yourself comfortable until the image is generated ;-\)\n\n") if ($gmap);
+
     my $black   = $im->colorAllocate(0  ,0  ,0  ); ### black
     my $white   = $im->colorAllocate(255,255,255); ### white
     my $momo    = $im->colorAllocate(255,127,127); ### momo
@@ -2113,6 +2131,8 @@ sub dnawalk{
     binmode NEW;
     print NEW $im->png;
     close NEW;
+
+    generateGMap("graph/". $gb->{LOCUS}->{id} . ".png") if($gmap);
 }
 
 1;
