@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Markov.pm,v 1.1.1.1 2002/04/02 20:25:41 gaou Exp $
@@ -32,21 +30,12 @@ use SubOpt;
 use G::Messenger;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	     markov
+our @EXPORT = qw(
+		 markov
 );
-$VERSION = '0.01';
 
 
 __DATA__
