@@ -199,7 +199,9 @@ sub splitprintseq {
 sub to_fasta{
     SubOpt::opt_default(length=>60, filename=>"out.fasta", name=>"sequence", output=>"f");
     my @args = SubOpt::opt_get(@_);
-    my $gb = SubOpt::opt_as_gb(shift @args);
+    my $first = shift @args;
+    die("Error: No sequence passed to to_fasta") unless(length($first));
+    my $gb = SubOpt::opt_as_gb($first);
     my $filename = SubOpt::opt_val("filename");
     my $name = SubOpt::opt_val("name");
     my $length = SubOpt::opt_val("length");
