@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Reader.pm,v 1.8 2002/04/01 14:19:54 t98901ka Exp $
@@ -30,21 +28,14 @@ package G::SystemsBiology::BioLayout;
 
 use SubOpt;
 use G::Messenger;
-#use G::SystemsBiology::EcellReader;
-use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
+use strict;
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	     enzyme_layout
-	     substance_layout	     
+our @EXPORT = qw(
+		 enzyme_layout
+		 substance_layout	     
 );
 
 
@@ -254,37 +245,4 @@ if($output eq "show"){
 }
 
 
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Ecell::BioLayout - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Ecell::BioLayout;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Ecell::BioLayout was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-Seira Nakamura, seira@g-language.org
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
