@@ -93,7 +93,7 @@ __DATA__
                  Image width size is 2^(level - 1) * 256, so width at
                  level = 6 is 8192. 
     -javascript  string of javascript code to place within the generated HTML file
-    -posterize   posterize option for ImageMagick (default: 16)
+    -colors      number of colors (default: 255)
 
   References:
     1. Google Maps API Documentation. http://www.google.com/apis/maps/documentation/
@@ -102,21 +102,23 @@ __DATA__
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20080911-01 replaced -posterize option with -colors
+    20080909-01 slightly changed the algorithm to make it about twice faster
     20080509-01 added -posterize option
     20070707-01 stopped tiling in the x-direction by default
     20070621-01 initial posting
-
+    
 =cut
 
 
 
 sub generateGMap{
-    opt_default(level=>6, format=>"gif", posterize=>16);
+    opt_default(level=>6, posterize=>16, colors=>255);
     my @argv = opt_get(@_);
     my $file = shift @argv;
     my $level = opt_val("level");
     my $javascript = opt_val("javascript");
-    my $posterize = opt_val("posterize");
+    my $posterize = opt_val("colors");
     $level = 3 if ($level < 3);
 
     my $filename = basename($file);
@@ -136,9 +138,14 @@ sub generateGMap{
 	die("Either ImageMagick is not available, or the given file is not a proper image.");
     }
     
+    my $maxwidth = 256 * 2 ** ($level - 1);
     
     if($width == $height){
-	system(sprintf("convert +dither -posterize $posterize %s %s/%s.png", $file, $name, $name));
+	if($width == $maxwidth && $file =~ /png$/){
+	    system(sprintf("cp %s %s/level%d.png", $file, $name, $level - 1));
+	}else{
+	    system(sprintf("convert +dither -colors $posterize -size %dx%d -resize %dx%d %s %s/level%d.png", $width, $height, $maxwidth, $maxwidth, $file, $name, $level - 1));
+	}
     }else{
 	my ($xdif, $ydif, $size) = (0,0, $width);
 	
@@ -149,29 +156,41 @@ sub generateGMap{
 	    $size = $height;
 	    $xdif = int(($height - $width) / 2);
 	}
-	print "HAGE";
-	system(sprintf("convert +dither -posterize $posterize -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
+
+	system(sprintf("convert +dither -colors $posterize -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
+	system(sprintf("convert +dither -colors $posterize %s/%s.png -size %dx%d -resize %dx%d %s/level%d.png", $name, $name, $size, $size, $maxwidth, $maxwidth, $name, $level - 1));
     }
     chdir($name);
-    
-    for(my $i = 0; $i < $level; $i ++){
+
+    my $maxlevel = $level - 1;
+
+    for(my $i = $maxlevel; $i >= 0; $i --){
 	my $tiles = 2 ** $i;
 	my $size = $tiles * 256;
-	
-	system(sprintf("convert +dither -posterize $posterize %s.png -resize %dx%d level$i.png", $name, $size, $size, $i));
-	system("convert +dither -posterize $posterize level$i.png -crop 256x256 level$i-%d.png");
-	
+
+	my $pid = fork();
+
+	if($pid){
+	}elsif(defined $pid){
+	    my $j = $i - 1;
+	    exit if ($j < 0);
+	    system(sprintf("convert +dither -colors $posterize level%d.png -size %dx%d -resize %dx%d level%d.png", $i, $size, $size, $size/2, $size/2, $j)) unless(-e "level$j.png");
+	    exit;
+	}else{
+	    die("fork failed.");
+	}
+
+	system("convert +dither -colors $posterize level$i.png -crop 256x256 level$i-%d.png");
+
 	for(my $y = 1; $y <= $tiles; $y ++){
 	    for(my $x = 1; $x <= $tiles; $x ++){
-		system(sprintf("mv level%d-%d.png level%d-%d-%d.png", $i, ($y - 1) * $tiles + ($x - 1), $i, $x - 1, $y - 1));
+		rename(sprintf("level%d-%d.png", $i, ($y - 1) * $tiles + ($x - 1)), sprintf("level%d-%d-%d.png", $i, $x - 1, $y - 1));
 	    }
 	}
-	
-    }
-    
 
-    my $resolution = $level - 1;
-    
+	waitpid($pid, 0);
+    }
+ 
     open(OUT, '>' . 'index.html') || die($!);
     
     print OUT << "__HTML__";
@@ -227,7 +246,7 @@ sub generateGMap{
         copyrightCollection.addCopyright(copyright);
 
        // Create a new Mercator projection instance 
-        var zoomlevel = $resolution;
+        var zoomlevel = $maxlevel;
 	var projection = new GMercatorProjection(zoomlevel + 1); 
 
        // add an exposed copy of the tileBounds array 
