@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -29,20 +27,13 @@
 
 package G::Tools::Statistics;
 
-use strict;
 use SubOpt;
 use G::Messenger;
-use Statistics::Descriptive;
-use Statistics::LineFit;
-use Statistics::RankCorrelation;
-use Statistics::Distributions;
-use Statistics::TTest;
-use Statistics::DependantTTest;
 
-require Exporter;
+use strict;
+use base qw(Exporter);
+use SelfLoader;
 
-our $VERSION = '1.00';
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 		 mean
 		 sum
@@ -58,6 +49,7 @@ our @EXPORT = qw(
 		 ttest
 		 );
 
+__DATA__
 
 #::::::::::::::::::::::::::::::
 #          PerlDoc
@@ -122,6 +114,7 @@ This library is a part of G-language GAE.
 =cut
 
 sub mean{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->mean();
@@ -152,6 +145,7 @@ sub mean{
 =cut
 
 sub sum{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->sum();
@@ -182,6 +176,7 @@ sub sum{
 =cut
 
 sub variance{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->variance();
@@ -212,6 +207,7 @@ sub variance{
 =cut
 
 sub standard_deviation{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->standard_deviation();
@@ -242,6 +238,7 @@ sub standard_deviation{
 =cut
 
 sub min{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->min();
@@ -272,6 +269,7 @@ sub min{
 =cut
 
 sub max{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->max();
@@ -302,6 +300,7 @@ sub max{
 =cut
 
 sub mindex{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->mindex();
@@ -332,6 +331,7 @@ sub mindex{
 =cut
 
 sub maxdex{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->maxdex();
@@ -362,6 +362,7 @@ sub maxdex{
 =cut
 
 sub median{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
     return $stat->median();
@@ -404,6 +405,7 @@ sub median{
 =cut
 
 sub least_squares_fit{
+    require Statistics::Descriptive;
     my $stat = Statistics::Descriptive::Full->new();
     $stat->add_data(@_); 
 
@@ -464,12 +466,14 @@ sub cor{
     my $sorted = opt_val("sorted");
 
     if($method eq 'spearman' || $method eq 'kendall'){
+	require Statistics::RankCorrelation;
 	my $stat = Statistics::RankCorrelation->new(@args, sorted=>$sorted);
 
 	return $stat->spearman if($method eq 'spearman');
 	return $stat->kendall_tau if($method eq 'kendall');
 
     }else{
+	require Statistics::LineFit;
 	my $stat = Statistics::LineFit->new();
 	$stat->setData(@args) or die("G::Tools::Statistics::cor  -  Invalid data"); 
 	my ($intercept, $slope) = $stat->coefficients();
@@ -526,12 +530,15 @@ sub ttest{
     my ($t_value, $p_value, $df);
 
     if($paired){
+	require Statistics::DependantTTest;
+	require Statistics::Distributions;
 	my $stat = new Statistics::DependantTTest;
 	$stat->load_data('x',@{$args[0]});
 	$stat->load_data('y',@{$args[1]});
 	($t_value,$df) = $stat->perform_t_test('x','y');
 	$p_value = Statistics::Distributions::tprob ($df, $t_value);
     }else{
+	require Statistics::TTest;
 	my $stat = new Statistics::TTest;  
 	$stat->load_data(@args);  
 
